@@ -15,6 +15,64 @@ Simple usage example:
     >>> print(euro)
     €1.00
 
+## Formatting
+
+The `multicurrency.currency.Currency` class allows you to create and
+customize your own value formatting behaviors using the same
+implementation as the built-in `format()` method.
+
+The specification for the formatting feature is as follows:
+
+    [dp][ds][gs][gp][spec]
+
+The meaning of the various alignment options is as follows:
+
+| Option | Type   | Meaning                                                                               |
+|:-------|:-------|:--------------------------------------------------------------------------------------|
+| [dp]   | int+   | The number of decimal places (integer number with one or more digits).                |
+| [ds]   | str{1} | The decimal sign (single non-digit character).                                        |
+| [gs]   | str{1} | The grouping sign (single non-digit character).                                       |
+| [gp]   | int+   | The number of digits to group the number by (integer number with one or more digits). |
+| [spec] | str    | The formatting spec (a strig with the order of currency parts).                       |
+
+All fields are optional although for the first four fields when setting
+one the fields on the left of that are required to be set as well.
+
+The available string currency parts for `[spec]` are:
+
+| Part | Meaning                                                                                                                     |
+|:-----|:----------------------------------------------------------------------------------------------------------------------------|
+| %a   | The currency's amount as seen in the default representation of the currency (the numeral system of the currency's country). |
+| %A   | The currency's amount in (western) arabic numerals.                                                                         |
+| %c   | The currency's alpha code (as seen on the international representation of the currency).                                    |
+| %s   | The currency's symbol.                                                                                                      |
+| %S   | The currency's localized symbol.                                                                                                      |
+| %_   | The currency's symbol separator.                                                                                            |
+
+Basic examples of how to use the `multicurrency.currency.Currency`
+formatting feature:
+
+    Using the built-in `format()` method
+
+        >>> from multicurrency import Euro
+        >>> euro = Euro(1000000*(1/7))
+        >>> format(euro, '4%a')
+        '142.857,1429'
+
+    Using the `'new' string` formating method
+
+        >>> from multicurrency import Euro
+        >>> euro = Euro(1000000*(1/7))
+        >>> '{:4%a}'.format(euro)
+        '142.857,1429'
+
+    Using the `f-string` method
+
+        >>> from multicurrency import Euro
+        >>> euro = Euro(1000000*(1/7))
+        >>> f'{euro:4%a}'
+        '142.857,1429'
+
 ## Supported operations
 
 Several operations are supported by the `multicurrency.currency.Currency`
@@ -127,7 +185,7 @@ the quotient of the division of the currency by either an `int`,
 Produces a hash representation of the `multicurrency.currency.Currency`.
 
     >>> from multicurrency import Currency
-    >>> hash(Currency(amount=7, alpha_code='EUR', numeric_code='978'))
+    >>> hash(Currency(7, alpha_code='EUR', numeric_code='978') # doctest: +SKIP
     1166476495300974230
 
 ### Int
@@ -200,34 +258,55 @@ objects of the same currency.
     False
     >>> c1 != c2
     True
-"""
+"""  # pylint: disable=line-too-long
 
 from decimal import Decimal, Context
-from typing import Any, Optional, Union
+from re import (
+    escape as _escape,
+    compile as _compile,
+    match as _match,
+    sub as _sub)
+from typing import Any, Optional, Tuple, Union
 from .exceptions import (
     CurrencyInvalidDivision,
     CurrencyInvalidMultiplication,
     CurrencyMismatchException,
     CurrencyTypeException)
 
+DEFAULT_PRECISION: int = 28
+"""Currency default precision.
 
-CurrencyContext: Context = Context(prec=28, rounding='ROUND_HALF_EVEN').copy()
+Holds the default value for the currency rounding precision (`28`).
+"""
+
+DEFAULT_ROUNDING: str = 'ROUND_HALF_EVEN'
+"""Currency default rounding method.
+
+Holds the default value for the currency rounding method
+(`ROUND_HALF_EVEN`).
+"""
+
+CurrencyContext: Context = Context(
+    prec=DEFAULT_PRECISION,
+    rounding=DEFAULT_ROUNDING).copy()
 """Currency Context.
 The environment for arithmetic operations involving `Currency`. This
 context manages the operations precision and the rounding method.
 
 Args:
-    prec (int): Precision. Defaults to `28`.
-    rounding (str): Rounding method. Defaults to `ROUND_HALF_EVEN`.
+    prec (int): Precision. Defaults to `DEFAULT_PRECISION`.
+    rounding (str): Rounding method. Defaults to `DEFAULT_ROUNDING`.
         Possible values are:
 
         * ROUND_CEILING: Round towards Infinity.
         * ROUND_DOWN: Round towards zero.
         * ROUND_FLOOR: Round towards negative Infinity.
-        * ROUND_HALF_DOWN: Round to nearest with ties going towards zero.
+        * ROUND_HALF_DOWN: Round to nearest with ties going towards
+            zero.
         * ROUND_HALF_EVEN: Round to nearest with ties going to nearest
             even integer.
-        * ROUND_HALF_UP: Round to nearest with ties going away from zero.
+        * ROUND_HALF_UP: Round to nearest with ties going away from
+            zero.
         * ROUND_UP: Round away from zero.
         * ROUND_05UP: Round away from zero if last digit after rounding
             towards zero would have been 0 or 5; otherwise round
@@ -244,6 +323,17 @@ Usage example:
     >>> CurrencyContext.rounding = 'ROUND_HALF_UP'
     >>> print(CurrencyContext.prec, CurrencyContext.rounding)
     4 ROUND_HALF_UP
+
+Default values can be restored with:
+
+    >>> from multicurrency import (
+    ...     CurrencyContext,
+    ...     DEFAULT_PRECISION,
+    ...     DEFAULT_ROUNDING)
+    >>> CurrencyContext.prec = DEFAULT_PRECISION
+    >>> CurrencyContext.rounding = DEFAULT_ROUNDING
+    >>> print(CurrencyContext.prec, CurrencyContext.rounding)
+    28 ROUND_HALF_EVEN
 """
 
 
@@ -293,9 +383,13 @@ class Currency:
             and the value. Defaults to ''.
         symbol_ahead (bool, optional): True if symbol goes ahead of the
             value. False otherwise. Defaults to False.
+        localized_symbol ((str, optional)): Represented currency
+            localizedsymbol. Defaults to the value of `symbol`.
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 2,
         decimal_sign (str, optional): Decimal symbol. Defaults to '.'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to ','.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -310,8 +404,10 @@ class Currency:
         '_convertion',
         '_decimal_places',
         '_decimal_sign',
+        '_grouping_places',
         '_grouping_sign',
         '_international',
+        '_localized_symbol',
         '_numeric_code',
         '_symbol',
         '_symbol_ahead',
@@ -325,8 +421,10 @@ class Currency:
             symbol: Optional[str] = '',
             symbol_ahead: Optional[bool] = True,
             symbol_separator: Optional[str] = '',
+            localized_symbol: Optional[str] = '',
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = '.',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = ',',
             convertion: Optional[str] = '',
             international: Optional[bool] = False) -> 'Currency':
@@ -340,8 +438,10 @@ class Currency:
         self._alpha_code = alpha_code
         self._decimal_places = max(decimal_places, 0)
         self._decimal_sign = decimal_sign
+        self._grouping_places = max(grouping_places, 0)
         self._grouping_sign = grouping_sign
         self._international = international
+        self._localized_symbol = localized_symbol or symbol
         self._numeric_code = numeric_code
         self._symbol = symbol
         self._symbol_ahead = symbol_ahead
@@ -365,8 +465,10 @@ class Currency:
             symbol=self._symbol,
             symbol_ahead=self._symbol_ahead,
             symbol_separator=self._symbol_separator,
+            localized_symbol=self._localized_symbol,
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
+            grouping_places=self._grouping_places,
             grouping_sign=self._grouping_sign,
             convertion=self._convertion,
             international=self._international)
@@ -397,8 +499,10 @@ class Currency:
             symbol=self._symbol,
             symbol_ahead=self._symbol_ahead,
             symbol_separator=self._symbol_separator,
+            localized_symbol=self._localized_symbol,
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
+            grouping_places=self._grouping_places,
             grouping_sign=self._grouping_sign,
             convertion=self._convertion,
             international=self._international)
@@ -424,8 +528,10 @@ class Currency:
             symbol=self._symbol,
             symbol_ahead=self._symbol_ahead,
             symbol_separator=self._symbol_separator,
+            localized_symbol=self._localized_symbol,
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
+            grouping_places=self._grouping_places,
             grouping_sign=self._grouping_sign,
             convertion=self._convertion,
             international=self._international)
@@ -443,13 +549,15 @@ class Currency:
             symbol=self._symbol,
             symbol_ahead=self._symbol_ahead,
             symbol_separator=self._symbol_separator,
+            localized_symbol=self._localized_symbol,
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
+            grouping_places=self._grouping_places,
             grouping_sign=self._grouping_sign,
             convertion=self._convertion,
             international=self._international)
 
-    def __divmod__(self, other: Any) -> tuple['Currency', 'Currency']:
+    def __divmod__(self, other: Any) -> Tuple['Currency', 'Currency']:
         """Returns a pair with the quocient and remaider of the
         division by `other`.
 
@@ -457,7 +565,7 @@ class Currency:
             other (Numerical): amount to divide by.
 
         Returns:
-            tuple['Currency', 'Currency']: quotient, remainder.
+            Tuple['Currency', 'Currency']: quotient, remainder.
 
         Raises:
             CurrencyInvalidDivision: If `other` not of types
@@ -478,8 +586,10 @@ class Currency:
                 symbol=self._symbol,
                 symbol_ahead=self._symbol_ahead,
                 symbol_separator=self._symbol_separator,
+                localized_symbol=self._localized_symbol,
                 decimal_places=self._decimal_places,
                 decimal_sign=self._decimal_sign,
+                grouping_places=self._grouping_places,
                 grouping_sign=self._grouping_sign,
                 convertion=self._convertion,
                 international=self._international),
@@ -490,8 +600,10 @@ class Currency:
                 symbol=self._symbol,
                 symbol_ahead=self._symbol_ahead,
                 symbol_separator=self._symbol_separator,
+                localized_symbol=self._localized_symbol,
                 decimal_places=self._decimal_places,
                 decimal_sign=self._decimal_sign,
+                grouping_places=self._grouping_places,
                 grouping_sign=self._grouping_sign,
                 convertion=self._convertion,
                 international=self._international))
@@ -505,11 +617,10 @@ class Currency:
         Returns:
             bool: True if equal. False otherwise.
         """
-        # if isinstance(other, Currency):
         if isinstance(other, self.__class__):
             return (
-                (self.amount == other.amount) and
-                (self._alpha_code == other.alpha_code))
+                (self._amount, self._alpha_code) ==
+                (other.amount, other.alpha_code))
         return False
 
     def __float__(self) -> float:
@@ -533,8 +644,10 @@ class Currency:
             symbol=self._symbol,
             symbol_ahead=self._symbol_ahead,
             symbol_separator=self._symbol_separator,
+            localized_symbol=self._localized_symbol,
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
+            grouping_places=self._grouping_places,
             grouping_sign=self._grouping_sign,
             convertion=self._convertion,
             international=self._international)
@@ -566,12 +679,108 @@ class Currency:
             symbol=self._symbol,
             symbol_ahead=self._symbol_ahead,
             symbol_separator=self._symbol_separator,
+            localized_symbol=self._localized_symbol,
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
+            grouping_places=self._grouping_places,
             grouping_sign=self._grouping_sign,
             convertion=self._convertion,
             international=self._international)
 
+    def __format__(self, fmt: str = '') -> str:
+        """Returns the result of applying the formating specs to the
+        currency value.
+
+        The formating spec is as follow:
+            '[dp][ds][gs][gp][spec]'
+
+        The fields are:
+            [dp] (int+): The number of decimal places (integer number
+                with one or more digits).
+            [ds] (char{1}): The decimal sign (single non-digit
+                character).
+            [gs] (char{1}): The grouping sign (single non-digit
+                character).
+            [gp] (int+): The number of digits to group the number by
+                (integer number with one or more digits).
+            [spec] (str): The formatting spec (a strig with the order
+                of currency parts).
+
+        The currency parts that can be used on the `spec` string are:
+            %a: The currency's amount as seen in the default
+                representation of the currency (the numeral system of
+                the currency's country).
+            %A: The currency's amount in (western) arabic numerals.
+            %c: The currency's alpha code (as seen on the international
+                representation of the currency).
+            %s: The currency's symbol.
+            %S: The currency's localized symbol.
+            %_: The currency's symbol separator.
+
+        All fields are optional although for the first four fields when
+        setting one the fields on the left of that are required to be
+        set as well.
+
+        Args:
+            fmt (str): formating spec.
+
+        Returns:
+            str: Formated currency value.
+
+        Raises:
+            TypeError: If `fmt` not of type `str`.
+            ValueError: If invalid `fmt` format.
+        """
+        if not isinstance(fmt, str):
+            raise TypeError(f'must be str, not {type(fmt).__name__}.')
+        if not fmt.strip():   # maybe fmt shoud be striped by default?
+            return self.__str__()
+        regxpr = (
+            r'^(?P<decimal_places>\d*)'
+            r'(?P<decimal_sign>[^\d%]?)'
+            r'(?P<grouping_sign>[^\d%]?)'
+            r'(?P<grouping_places>\d*)'
+            r'(?P<format>%.*|$)')
+        matches = _match(regxpr, fmt)
+        if not matches:
+            raise ValueError('invalid format.')
+        decimal_places = max(
+            int(matches.group('decimal_places') or self._decimal_places), 0)
+        decimal_sign = matches.group('decimal_sign') or self._decimal_sign
+        grouping_sign = matches.group('grouping_sign') or self._grouping_sign
+        grouping_places = int(
+            matches.group('grouping_places') or self._grouping_places)
+        currency_format = matches.group('format')
+        amount = _sub(
+            rf'(\d)(?=(\d{{{grouping_places or -1}}})+\.)',
+            r'\1,',
+            f'{round(self._amount, decimal_places or 1)}')
+        if decimal_places < 1:
+            amount = amount.split('.')[0]
+        converted = amount
+        if self._convertion:
+            t = dict(zip('0123456789-', self._convertion))
+            converted = ''.join([t.get(c, c) for c in converted])
+        converted = converted.replace('.', 'X').replace(
+            ',', grouping_sign).replace('X', decimal_sign)
+        if not currency_format:
+            if self._symbol_ahead:
+                return f'{self._symbol}{self._symbol_separator}{converted}'
+            return f'{converted}{self._symbol_separator}{self._symbol}'
+        rep = {
+            '%s': self._symbol,
+            '%S': self._localized_symbol,
+            '%c': self._alpha_code,
+            '%a': converted,
+            '%A': amount,
+            '%_': self._symbol_separator}
+        rep = dict((_escape(k), v) for k, v in rep.items())
+        pattern = _compile('|'.join(rep.keys()))
+        formatted = pattern.sub(
+            lambda m: rep[_escape(m.group(0))],
+            currency_format)
+        return formatted
+
     def __ge__(self, other: Any) -> bool:
         """Checks if self is greater or equal than `other`.
 
@@ -621,7 +830,11 @@ class Currency:
         Returns:
             int: Hash value.
         """
-        return hash((self._amount, self._alpha_code, self._numeric_code))
+        return hash((
+            self.__class__,
+            self._amount,
+            self._alpha_code,
+            self._numeric_code))
 
     def __int__(self) -> int:
         """Integer representation.
@@ -700,8 +913,10 @@ class Currency:
             symbol=self._symbol,
             symbol_ahead=self._symbol_ahead,
             symbol_separator=self._symbol_separator,
+            localized_symbol=self._localized_symbol,
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
+            grouping_places=self._grouping_places,
             grouping_sign=self._grouping_sign,
             convertion=self._convertion,
             international=self._international)
@@ -728,8 +943,10 @@ class Currency:
             symbol=self._symbol,
             symbol_ahead=self._symbol_ahead,
             symbol_separator=self._symbol_separator,
+            localized_symbol=self._localized_symbol,
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
+            grouping_places=self._grouping_places,
             grouping_sign=self._grouping_sign,
             convertion=self._convertion,
             international=self._international)
@@ -758,8 +975,10 @@ class Currency:
             symbol=self._symbol,
             symbol_ahead=self._symbol_ahead,
             symbol_separator=self._symbol_separator,
+            localized_symbol=self._localized_symbol,
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
+            grouping_places=self._grouping_places,
             grouping_sign=self._grouping_sign,
             convertion=self._convertion,
             international=self._international)
@@ -777,17 +996,19 @@ class Currency:
             symbol=self._symbol,
             symbol_ahead=self._symbol_ahead,
             symbol_separator=self._symbol_separator,
+            localized_symbol=self._localized_symbol,
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
+            grouping_places=self._grouping_places,
             grouping_sign=self._grouping_sign,
             convertion=self._convertion,
             international=self._international)
 
-    def __reduce__(self) -> tuple[type, tuple[Any, ...]]:
+    def __reduce__(self) -> Tuple[type, Tuple[Any, ...]]:
         """.
 
         Returns:
-            tuple[type, tuple[Any, ...]]: pickle representation of this
+            Tuple[type, Tuple[Any, ...]]: pickle representation of this
                 currency.
         """
         return (
@@ -799,8 +1020,10 @@ class Currency:
                 self._symbol,
                 self._symbol_ahead,
                 self._symbol_separator,
+                self._localized_symbol,
                 self._decimal_places,
                 self._decimal_sign,
+                self._grouping_places,
                 self._grouping_sign,
                 self._convertion,
                 self._international))
@@ -818,9 +1041,11 @@ class Currency:
             f'symbol: "{self._symbol}", '
             f'symbol_ahead: {self._symbol_ahead}, '
             f'symbol_separator: "{self._symbol_separator}", '
+            f'localized_symbol: "{self._localized_symbol}", '
             f'numeric_code: "{self._numeric_code}", '
             f'decimal_places: "{self._decimal_places}", '
             f'decimal_sign: "{self._decimal_sign}", '
+            f'grouping_places: "{self._grouping_places}", '
             f'grouping_sign: "{self._grouping_sign}", '
             f'convertion: "{self._convertion}", '
             f'international: {self._international})')
@@ -842,8 +1067,45 @@ class Currency:
             symbol=self._symbol,
             symbol_ahead=self._symbol_ahead,
             symbol_separator=self._symbol_separator,
+            localized_symbol=self._localized_symbol,
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
+            grouping_places=self._grouping_places,
+            grouping_sign=self._grouping_sign,
+            convertion=self._convertion,
+            international=self._international)
+
+    def __rsub__(self, other: Any) -> 'Currency':
+        """Subtract this from `other`.
+
+        Args:
+            other (multicurrency.currency.Currency): Currency to
+                subtract from.
+
+        Returns:
+            Currency: result of the subtraction operation.
+
+        Raises:
+            CurrencyTypeException: If `other` not instance of
+                'Currency'.
+            CurrencyMismatchException: If `other.alpha_code` is
+                differente from `alpha_code`.
+        """
+        if not isinstance(other, self.__class__):
+            raise CurrencyTypeException(other, self)
+        if self._alpha_code != other.alpha_code:
+            raise CurrencyMismatchException(other.alpha_code, self._alpha_code)
+        return self.__class__(
+            amount=other.amount - self._amount,
+            alpha_code=self._alpha_code,
+            numeric_code=self._numeric_code,
+            symbol=self._symbol,
+            symbol_ahead=self._symbol_ahead,
+            symbol_separator=self._symbol_separator,
+            localized_symbol=self._localized_symbol,
+            decimal_places=self._decimal_places,
+            decimal_sign=self._decimal_sign,
+            grouping_places=self._grouping_places,
             grouping_sign=self._grouping_sign,
             convertion=self._convertion,
             international=self._international)
@@ -854,24 +1116,14 @@ class Currency:
         Returns:
             str: value
         """
-        p = self._decimal_places
-        converted = f'{round(self._amount, p):,.{p}f}'
-        if self._international:
-            return f'{self._alpha_code} {converted}'
-        if self._convertion:
-            t = dict(zip('0123456789-', self._convertion))
-            converted = ''.join([t.get(c, c) for c in converted])
-        converted = converted.replace('.', 'X').replace(
-            ',', self._grouping_sign).replace('X', self._decimal_sign)
-        if self._symbol_ahead:
-            return f'{self._symbol}{self._symbol_separator}{converted}'
-        return f'{converted}{self._symbol_separator}{self._symbol}'
+        return self.pstr(precision=self._decimal_places)
 
     def __sub__(self, other: Any) -> 'Currency':
         """Subtract `other` from this.
 
         Args:
-            other (multicurrency.currency.Currency): Currency to subtract.
+            other (multicurrency.currency.Currency): Currency to
+                subtract.
 
         Returns:
             Currency: result of the subtraction operation.
@@ -893,8 +1145,10 @@ class Currency:
             symbol=self._symbol,
             symbol_ahead=self._symbol_ahead,
             symbol_separator=self._symbol_separator,
+            localized_symbol=self._localized_symbol,
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
+            grouping_places=self._grouping_places,
             grouping_sign=self._grouping_sign,
             convertion=self._convertion,
             international=self._international)
@@ -925,12 +1179,15 @@ class Currency:
             symbol=self._symbol,
             symbol_ahead=self._symbol_ahead,
             symbol_separator=self._symbol_separator,
+            localized_symbol=self._localized_symbol,
             decimal_places=self._decimal_places,
             decimal_sign=self._decimal_sign,
+            grouping_places=self._grouping_places,
             grouping_sign=self._grouping_sign,
             convertion=self._convertion,
             international=self._international)
 
+    __deepcopy__: 'Currency' = __copy__
     __rmul__: 'Currency' = __mul__
 
     def is_signed(self) -> bool:
@@ -942,6 +1199,39 @@ class Currency:
         """
         return self._amount.is_signed()
 
+    def lstr(self, precision: int = 2) -> str:
+        """String value of this class formated with the
+            `localized_symbol` and the `CurrencyContext` precision
+            value (`prec`).
+
+        Args:
+            precision (int, optional): Precision. Defaults to `2`.
+                Values lower than 0 (zero) will be converted to 0
+                (zero).
+
+        Returns:
+            str: value
+        """
+        p = max(precision, 0)
+        _rounded = str(round(self._amount, p))
+        if not p:
+            _rounded = f'{_rounded}.'
+        converted = _sub(
+            rf'(\d)(?=(\d{{{self._grouping_places or -1}}})+\.)',
+            r'\1,',
+            _rounded)
+        if not p:
+            converted = converted[:-1]
+        if self._convertion:
+            t = dict(zip('0123456789-', self._convertion))
+            converted = ''.join([t.get(c, c) for c in converted])
+        converted = converted.replace('.', 'X').replace(
+            ',', self._grouping_sign).replace('X', self._decimal_sign)
+        if self._symbol_ahead:
+            return (
+                f'{self._localized_symbol}{self._symbol_separator}{converted}')
+        return f'{converted}{self._symbol_separator}{self._localized_symbol}'
+
     def pstr(self, precision: int = 2) -> str:
         """String value of this class formated with
             `CurrencyContext` precision value (`prec`).
@@ -955,7 +1245,15 @@ class Currency:
             str: value
         """
         p = max(precision, 0)
-        converted = f'{round(self._amount, p):,.{p}f}'
+        _rounded = str(round(self._amount, p))
+        if not p:
+            _rounded = f'{_rounded}.'
+        converted = _sub(
+            rf'(\d)(?=(\d{{{self._grouping_places or -1}}})+\.)',
+            r'\1,',
+            _rounded)
+        if not p:
+            converted = converted[:-1]
         if self._international:
             return f'{self._alpha_code} {converted}'
         if self._convertion:
@@ -997,6 +1295,11 @@ class Currency:
         """str: decimal_sign."""
         return self._decimal_sign
 
+    @property
+    def grouping_places(self) -> int:
+        """int: grouping_places."""
+        return self._grouping_places
+
     @property
     def grouping_sign(self) -> str:
         """str: grouping_sign."""
@@ -1007,6 +1310,11 @@ class Currency:
         """bool: international."""
         return self._international
 
+    @property
+    def localized_symbol(self) -> str:
+        """str: localized_symbol."""
+        return self._localized_symbol
+
     @property
     def symbol(self) -> str:
         """str: symbol."""
