@@ -20,7 +20,7 @@ class BahrainiDinar(Currency):
         >>> bahraini_dinar = BahrainiDinar(
         ...     amount=123456.789)
         >>> print(bahraini_dinar)
-        ١٢٣٬٤٥٦٫٧٨٩ ب.د
+        د.ب. ١٢٣٬٤٥٦٫٧٨٩
 
     For more details see `multicurrency.currency.Currency` .
 
@@ -29,6 +29,8 @@ class BahrainiDinar(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 3,
         decimal_sign (str, optional): Decimal symbol. Defaults to '٫'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '٬'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -36,7 +38,7 @@ class BahrainiDinar(Currency):
         symbol_separator (str, optional): Separation between the symbol
             and the value. Defaults to ' '.
         symbol_ahead (bool, optional): True if symbol goes ahead of the
-            value. False otherwise. Defaults to False.
+            value. False otherwise. Defaults to True.
     """
 
     __slots__ = []
@@ -46,9 +48,10 @@ class BahrainiDinar(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 3,
             decimal_sign: Optional[str] = '\u066B',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '\u066C',
             international: Optional[bool] = False,
-            symbol_ahead: Optional[bool] = False,
+            symbol_ahead: Optional[bool] = True,
             symbol_separator: Optional[str] = '\u00A0',
             **other) -> 'BahrainiDinar':
         """Class creator.
@@ -61,11 +64,13 @@ class BahrainiDinar(Currency):
             amount=amount,
             alpha_code='BHD',
             numeric_code='048',
-            symbol='ب.د',
+            symbol='د.ب.',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='د.ب.',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='٠١٢٣٤٥٦٧٨٩-',
             international=international)
@@ -80,7 +85,7 @@ class AlgerianDinar(Currency):
         >>> algerian_dinar = AlgerianDinar(
         ...     amount=123456.789)
         >>> print(algerian_dinar)
-        123.456,79 د.ج
+        123.456,79 د.ج.
 
     For more details see `multicurrency.currency.Currency` .
 
@@ -89,6 +94,8 @@ class AlgerianDinar(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 2,
         decimal_sign (str, optional): Decimal symbol. Defaults to ','.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '.'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -106,6 +113,7 @@ class AlgerianDinar(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = ',',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '.',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = False,
@@ -121,11 +129,13 @@ class AlgerianDinar(Currency):
             amount=amount,
             alpha_code='DZD',
             numeric_code='012',
-            symbol='د.ج',
+            symbol='د.ج.',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='د.ج.',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='',
             international=international)
@@ -140,7 +150,7 @@ class IraqiDinar(Currency):
         >>> iraqi_dinar = IraqiDinar(
         ...     amount=123456.789)
         >>> print(iraqi_dinar)
-        ع.د ١٢٣٬٤٥٦٫٧٨٩
+        د.ع. ١٢٣٬٤٥٦٫٧٨٩
 
     For more details see `multicurrency.currency.Currency` .
 
@@ -149,6 +159,8 @@ class IraqiDinar(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 3,
         decimal_sign (str, optional): Decimal symbol. Defaults to '٫'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '٬'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -166,6 +178,7 @@ class IraqiDinar(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 3,
             decimal_sign: Optional[str] = '\u066B',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '\u066C',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = True,
@@ -181,11 +194,13 @@ class IraqiDinar(Currency):
             amount=amount,
             alpha_code='IQD',
             numeric_code='368',
-            symbol='ع.د',
+            symbol='د.ع.',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='د.ع.',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='٠١٢٣٤٥٦٧٨٩-',
             international=international)
@@ -200,7 +215,7 @@ class JordanianDinar(Currency):
         >>> jordanian_dinar = JordanianDinar(
         ...     amount=123456.789)
         >>> print(jordanian_dinar)
-        د.ا ١٢٣٬٤٥٦٫٧٨٩
+        د.أ. ١٢٣٬٤٥٦٫٧٨٩
 
     For more details see `multicurrency.currency.Currency` .
 
@@ -209,6 +224,8 @@ class JordanianDinar(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 3,
         decimal_sign (str, optional): Decimal symbol. Defaults to '٫'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '٬'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -226,6 +243,7 @@ class JordanianDinar(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 3,
             decimal_sign: Optional[str] = '\u066B',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '\u066C',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = True,
@@ -241,11 +259,13 @@ class JordanianDinar(Currency):
             amount=amount,
             alpha_code='JOD',
             numeric_code='400',
-            symbol='د.ا',
+            symbol='د.أ.',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='د.أ.',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='٠١٢٣٤٥٦٧٨٩-',
             international=international)
@@ -260,7 +280,7 @@ class KuwaitiDinar(Currency):
         >>> kuwaiti_dinar = KuwaitiDinar(
         ...     amount=123456.789)
         >>> print(kuwaiti_dinar)
-        د.ك ١٢٣٬٤٥٦٫٧٨٩
+        د.ك. ١٢٣٬٤٥٦٫٧٨٩
 
     For more details see `multicurrency.currency.Currency` .
 
@@ -269,6 +289,8 @@ class KuwaitiDinar(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 3,
         decimal_sign (str, optional): Decimal symbol. Defaults to '٫'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '٬'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -286,6 +308,7 @@ class KuwaitiDinar(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 3,
             decimal_sign: Optional[str] = '\u066B',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '\u066C',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = True,
@@ -301,11 +324,13 @@ class KuwaitiDinar(Currency):
             amount=amount,
             alpha_code='KWD',
             numeric_code='414',
-            symbol='د.ك',
+            symbol='د.ك.',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='د.ك.',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='٠١٢٣٤٥٦٧٨٩-',
             international=international)
@@ -320,7 +345,7 @@ class LibyanDinar(Currency):
         >>> libyan_dinar = LibyanDinar(
         ...     amount=123456.789)
         >>> print(libyan_dinar)
-        ل.د 123.456,789
+        د.ل. 123.456,789
 
     For more details see `multicurrency.currency.Currency` .
 
@@ -329,6 +354,8 @@ class LibyanDinar(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 3,
         decimal_sign (str, optional): Decimal symbol. Defaults to ','.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '.'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -346,6 +373,7 @@ class LibyanDinar(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 3,
             decimal_sign: Optional[str] = ',',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '.',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = True,
@@ -361,11 +389,13 @@ class LibyanDinar(Currency):
             amount=amount,
             alpha_code='LYD',
             numeric_code='434',
-            symbol='ل.د',
+            symbol='د.ل.',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='د.ل.',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='',
             international=international)
@@ -380,7 +410,7 @@ class SerbianDinarXK(Currency):
         >>> serbian_dinar_xk = SerbianDinarXK(
         ...     amount=123456.789)
         >>> print(serbian_dinar_xk)
-        123.456,79 дин
+        123.456,79 дин.
 
     For more details see `multicurrency.currency.Currency` .
 
@@ -389,6 +419,8 @@ class SerbianDinarXK(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 2,
         decimal_sign (str, optional): Decimal symbol. Defaults to ','.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '.'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -406,6 +438,7 @@ class SerbianDinarXK(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = ',',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '.',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = False,
@@ -421,11 +454,13 @@ class SerbianDinarXK(Currency):
             amount=amount,
             alpha_code='RSD',
             numeric_code='941',
-            symbol='дин',
+            symbol='дин.',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='дин.',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='',
             international=international)
@@ -440,7 +475,7 @@ class SerbianDinarSR(Currency):
         >>> serbian_dinar_sr = SerbianDinarSR(
         ...     amount=123456.789)
         >>> print(serbian_dinar_sr)
-        123 456,79 дин
+        123 456,79 дин.
 
     For more details see `multicurrency.currency.Currency` .
 
@@ -449,6 +484,8 @@ class SerbianDinarSR(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 2,
         decimal_sign (str, optional): Decimal symbol. Defaults to ','.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to ' '.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -466,6 +503,7 @@ class SerbianDinarSR(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = ',',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '\u202F',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = False,
@@ -481,11 +519,13 @@ class SerbianDinarSR(Currency):
             amount=amount,
             alpha_code='RSD',
             numeric_code='941',
-            symbol='дин',
+            symbol='дин.',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='дин.',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='',
             international=international)
@@ -500,7 +540,7 @@ class TunisianDinar(Currency):
         >>> tunisian_dinar = TunisianDinar(
         ...     amount=123456.789)
         >>> print(tunisian_dinar)
-        د.ت 123.456,789
+        د.ت. 123.456,789
 
     For more details see `multicurrency.currency.Currency` .
 
@@ -509,6 +549,8 @@ class TunisianDinar(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 3,
         decimal_sign (str, optional): Decimal symbol. Defaults to ','.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '.'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -526,6 +568,7 @@ class TunisianDinar(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 3,
             decimal_sign: Optional[str] = ',',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '.',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = True,
@@ -541,11 +584,13 @@ class TunisianDinar(Currency):
             amount=amount,
             alpha_code='TND',
             numeric_code='788',
-            symbol='د.ت',
+            symbol='د.ت.',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='د.ت.',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='',
             international=international)
