@@ -20,7 +20,7 @@ class BolivarFuerte(Currency):
         >>> bolivar_fuerte = BolivarFuerte(
         ...     amount=123456.789)
         >>> print(bolivar_fuerte)
-        Bs.F 123.456,79
+        Bs.F. 123.456,79
 
     For more details see `multicurrency.currency.Currency` .
 
@@ -29,6 +29,8 @@ class BolivarFuerte(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 2,
         decimal_sign (str, optional): Decimal symbol. Defaults to ','.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '.'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -46,6 +48,7 @@ class BolivarFuerte(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = ',',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '.',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = True,
@@ -61,11 +64,13 @@ class BolivarFuerte(Currency):
             amount=amount,
             alpha_code='VEF',
             numeric_code='937',
-            symbol='Bs.F',
+            symbol='Bs.F.',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='Bs.F.',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='',
             international=international)
