@@ -20,7 +20,7 @@ class BulgarianLev(Currency):
         >>> bulgarian_lev = BulgarianLev(
         ...     amount=123456.789)
         >>> print(bulgarian_lev)
-        123456,79 лв
+        123456,79 лв.
 
     For more details see `multicurrency.currency.Currency` .
 
@@ -29,6 +29,8 @@ class BulgarianLev(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 2,
         decimal_sign (str, optional): Decimal symbol. Defaults to ','.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to ''.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -46,6 +48,7 @@ class BulgarianLev(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = ',',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = False,
@@ -61,11 +64,13 @@ class BulgarianLev(Currency):
             amount=amount,
             alpha_code='BGN',
             numeric_code='975',
-            symbol='лв',
+            symbol='лв.',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='лв.',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='',
             international=international)
