@@ -20,7 +20,7 @@ class EgyptianPound(Currency):
         >>> egyptian_pound = EgyptianPound(
         ...     amount=123456.789)
         >>> print(egyptian_pound)
-        ج.م ١٢٣٬٤٥٦٫٧٩
+        ج.م. ١٢٣٬٤٥٦٫٧٩
 
     For more details see `multicurrency.currency.Currency` .
 
@@ -29,6 +29,8 @@ class EgyptianPound(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 2,
         decimal_sign (str, optional): Decimal symbol. Defaults to '٫'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '٬'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -46,6 +48,7 @@ class EgyptianPound(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = '\u066B',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '\u066C',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = True,
@@ -61,11 +64,13 @@ class EgyptianPound(Currency):
             amount=amount,
             alpha_code='EGP',
             numeric_code='818',
-            symbol='ج.م',
+            symbol='ج.م.',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='ج.م.',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='٠١٢٣٤٥٦٧٨٩-',
             international=international)
@@ -89,6 +94,8 @@ class FalklandIslandsPound(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 2,
         decimal_sign (str, optional): Decimal symbol. Defaults to '.'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to ','.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -106,6 +113,7 @@ class FalklandIslandsPound(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = '.',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = ',',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = True,
@@ -124,8 +132,10 @@ class FalklandIslandsPound(Currency):
             symbol='£',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='FK£',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='',
             international=international)
@@ -149,6 +159,8 @@ class PoundSterling(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 2,
         decimal_sign (str, optional): Decimal symbol. Defaults to '.'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to ','.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -166,6 +178,7 @@ class PoundSterling(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = '.',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = ',',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = True,
@@ -184,8 +197,270 @@ class PoundSterling(Currency):
             symbol='£',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='£',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
+            grouping_sign=grouping_sign,
+            convertion='',
+            international=international)
+
+
+class PoundSterlingGG(Currency):
+    """Pound Sterling GG currency representation.
+
+    Simple usage example:
+
+        >>> from multicurrency import PoundSterlingGG
+        >>> pound_sterling_gg = PoundSterlingGG(
+        ...     amount=123456.789)
+        >>> print(pound_sterling_gg)
+        £123,456.79
+
+    For more details see `multicurrency.currency.Currency` .
+
+    Args:
+        amount (Union[int, float, Decimal]): Represented value.
+        decimal_places (int, optional): Number of decimal places for the
+            currency representation. Defaults to 2,
+        decimal_sign (str, optional): Decimal symbol. Defaults to '.'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
+        grouping_sign (str, optional): Grouping symbol. Defaults to ','.
+        international (bool, optional): Identifies the currency using
+            the 'currency' value instead of the 'symbol'. Defaults to
+            False.
+        symbol_separator (str, optional): Separation between the symbol
+            and the value. Defaults to ''.
+        symbol_ahead (bool, optional): True if symbol goes ahead of the
+            value. False otherwise. Defaults to True.
+    """
+
+    __slots__ = []
+
+    def __new__(  # pylint: disable=signature-differs,disable=unused-argument
+            cls,
+            amount: Union[int, float, Decimal],
+            decimal_places: Optional[int] = 2,
+            decimal_sign: Optional[str] = '.',
+            grouping_places: Optional[int] = 3,
+            grouping_sign: Optional[str] = ',',
+            international: Optional[bool] = False,
+            symbol_ahead: Optional[bool] = True,
+            symbol_separator: Optional[str] = '',
+            **other) -> 'PoundSterlingGG':
+        """Class creator.
+
+        Returns:
+            PoundSterlingGG: new opbject.
+        """
+        return Currency.__new__(
+            cls,
+            amount=amount,
+            alpha_code='GBP',
+            numeric_code='826',
+            symbol='£',
+            symbol_separator=symbol_separator,
+            symbol_ahead=symbol_ahead,
+            localized_symbol='GG£',
+            decimal_places=decimal_places,
+            decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
+            grouping_sign=grouping_sign,
+            convertion='',
+            international=international)
+
+
+class PoundSterlingIO(Currency):
+    """Pound Sterling IO currency representation.
+
+    Simple usage example:
+
+        >>> from multicurrency import PoundSterlingIO
+        >>> pound_sterling_io = PoundSterlingIO(
+        ...     amount=123456.789)
+        >>> print(pound_sterling_io)
+        £123,456.79
+
+    For more details see `multicurrency.currency.Currency` .
+
+    Args:
+        amount (Union[int, float, Decimal]): Represented value.
+        decimal_places (int, optional): Number of decimal places for the
+            currency representation. Defaults to 2,
+        decimal_sign (str, optional): Decimal symbol. Defaults to '.'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
+        grouping_sign (str, optional): Grouping symbol. Defaults to ','.
+        international (bool, optional): Identifies the currency using
+            the 'currency' value instead of the 'symbol'. Defaults to
+            False.
+        symbol_separator (str, optional): Separation between the symbol
+            and the value. Defaults to ''.
+        symbol_ahead (bool, optional): True if symbol goes ahead of the
+            value. False otherwise. Defaults to True.
+    """
+
+    __slots__ = []
+
+    def __new__(  # pylint: disable=signature-differs,disable=unused-argument
+            cls,
+            amount: Union[int, float, Decimal],
+            decimal_places: Optional[int] = 2,
+            decimal_sign: Optional[str] = '.',
+            grouping_places: Optional[int] = 3,
+            grouping_sign: Optional[str] = ',',
+            international: Optional[bool] = False,
+            symbol_ahead: Optional[bool] = True,
+            symbol_separator: Optional[str] = '',
+            **other) -> 'PoundSterlingIO':
+        """Class creator.
+
+        Returns:
+            PoundSterlingIO: new opbject.
+        """
+        return Currency.__new__(
+            cls,
+            amount=amount,
+            alpha_code='GBP',
+            numeric_code='826',
+            symbol='£',
+            symbol_separator=symbol_separator,
+            symbol_ahead=symbol_ahead,
+            localized_symbol='IO£',
+            decimal_places=decimal_places,
+            decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
+            grouping_sign=grouping_sign,
+            convertion='',
+            international=international)
+
+
+class PoundSterlingGB(Currency):
+    """Pound Sterling GB currency representation.
+
+    Simple usage example:
+
+        >>> from multicurrency import PoundSterlingGB
+        >>> pound_sterling_gb = PoundSterlingGB(
+        ...     amount=123456.789)
+        >>> print(pound_sterling_gb)
+        £123,456.79
+
+    For more details see `multicurrency.currency.Currency` .
+
+    Args:
+        amount (Union[int, float, Decimal]): Represented value.
+        decimal_places (int, optional): Number of decimal places for the
+            currency representation. Defaults to 2,
+        decimal_sign (str, optional): Decimal symbol. Defaults to '.'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
+        grouping_sign (str, optional): Grouping symbol. Defaults to ','.
+        international (bool, optional): Identifies the currency using
+            the 'currency' value instead of the 'symbol'. Defaults to
+            False.
+        symbol_separator (str, optional): Separation between the symbol
+            and the value. Defaults to ''.
+        symbol_ahead (bool, optional): True if symbol goes ahead of the
+            value. False otherwise. Defaults to True.
+    """
+
+    __slots__ = []
+
+    def __new__(  # pylint: disable=signature-differs,disable=unused-argument
+            cls,
+            amount: Union[int, float, Decimal],
+            decimal_places: Optional[int] = 2,
+            decimal_sign: Optional[str] = '.',
+            grouping_places: Optional[int] = 3,
+            grouping_sign: Optional[str] = ',',
+            international: Optional[bool] = False,
+            symbol_ahead: Optional[bool] = True,
+            symbol_separator: Optional[str] = '',
+            **other) -> 'PoundSterlingGB':
+        """Class creator.
+
+        Returns:
+            PoundSterlingGB: new opbject.
+        """
+        return Currency.__new__(
+            cls,
+            amount=amount,
+            alpha_code='GBP',
+            numeric_code='826',
+            symbol='£',
+            symbol_separator=symbol_separator,
+            symbol_ahead=symbol_ahead,
+            localized_symbol='GB£',
+            decimal_places=decimal_places,
+            decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
+            grouping_sign=grouping_sign,
+            convertion='',
+            international=international)
+
+
+class PoundSterlingIM(Currency):
+    """Pound Sterling IM currency representation.
+
+    Simple usage example:
+
+        >>> from multicurrency import PoundSterlingIM
+        >>> pound_sterling_im = PoundSterlingIM(
+        ...     amount=123456.789)
+        >>> print(pound_sterling_im)
+        £123,456.79
+
+    For more details see `multicurrency.currency.Currency` .
+
+    Args:
+        amount (Union[int, float, Decimal]): Represented value.
+        decimal_places (int, optional): Number of decimal places for the
+            currency representation. Defaults to 2,
+        decimal_sign (str, optional): Decimal symbol. Defaults to '.'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
+        grouping_sign (str, optional): Grouping symbol. Defaults to ','.
+        international (bool, optional): Identifies the currency using
+            the 'currency' value instead of the 'symbol'. Defaults to
+            False.
+        symbol_separator (str, optional): Separation between the symbol
+            and the value. Defaults to ''.
+        symbol_ahead (bool, optional): True if symbol goes ahead of the
+            value. False otherwise. Defaults to True.
+    """
+
+    __slots__ = []
+
+    def __new__(  # pylint: disable=signature-differs,disable=unused-argument
+            cls,
+            amount: Union[int, float, Decimal],
+            decimal_places: Optional[int] = 2,
+            decimal_sign: Optional[str] = '.',
+            grouping_places: Optional[int] = 3,
+            grouping_sign: Optional[str] = ',',
+            international: Optional[bool] = False,
+            symbol_ahead: Optional[bool] = True,
+            symbol_separator: Optional[str] = '',
+            **other) -> 'PoundSterlingIM':
+        """Class creator.
+
+        Returns:
+            PoundSterlingIM: new opbject.
+        """
+        return Currency.__new__(
+            cls,
+            amount=amount,
+            alpha_code='GBP',
+            numeric_code='826',
+            symbol='£',
+            symbol_separator=symbol_separator,
+            symbol_ahead=symbol_ahead,
+            localized_symbol='IM£',
+            decimal_places=decimal_places,
+            decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='',
             international=international)
@@ -209,6 +484,8 @@ class GibraltarPound(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 2,
         decimal_sign (str, optional): Decimal symbol. Defaults to '.'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to ','.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -226,6 +503,7 @@ class GibraltarPound(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = '.',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = ',',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = True,
@@ -244,8 +522,10 @@ class GibraltarPound(Currency):
             symbol='£',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='GI£',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='',
             international=international)
@@ -260,7 +540,7 @@ class LebanesePound(Currency):
         >>> lebanese_pound = LebanesePound(
         ...     amount=123456.789)
         >>> print(lebanese_pound)
-        ل.ل ١٢٣٬٤٥٧
+        ل.ل. ١٢٣٬٤٥٧
 
     For more details see `multicurrency.currency.Currency` .
 
@@ -269,6 +549,8 @@ class LebanesePound(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 0,
         decimal_sign (str, optional): Decimal symbol. Defaults to '٫'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '٬'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -286,6 +568,7 @@ class LebanesePound(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 0,
             decimal_sign: Optional[str] = '\u066B',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '\u066C',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = True,
@@ -301,11 +584,13 @@ class LebanesePound(Currency):
             amount=amount,
             alpha_code='LBP',
             numeric_code='422',
-            symbol='ل.ل',
+            symbol='ل.ل.',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='ل.ل.',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='٠١٢٣٤٥٦٧٨٩-',
             international=international)
@@ -329,6 +614,8 @@ class SudanesePound(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 2,
         decimal_sign (str, optional): Decimal symbol. Defaults to '٫'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '٬'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -346,6 +633,7 @@ class SudanesePound(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = '\u066B',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '\u066C',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = False,
@@ -364,8 +652,10 @@ class SudanesePound(Currency):
             symbol='ج.س',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='ج.س',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='٠١٢٣٤٥٦٧٨٩-',
             international=international)
@@ -389,6 +679,8 @@ class SaintHelenaPound(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 2,
         decimal_sign (str, optional): Decimal symbol. Defaults to '.'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to ','.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -406,6 +698,7 @@ class SaintHelenaPound(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = '.',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = ',',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = True,
@@ -424,8 +717,10 @@ class SaintHelenaPound(Currency):
             symbol='£',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='SH£',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='',
             international=international)
@@ -449,6 +744,8 @@ class SyrianPound(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 2,
         decimal_sign (str, optional): Decimal symbol. Defaults to '٫'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '٬'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -466,6 +763,7 @@ class SyrianPound(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = '\u066B',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '\u066C',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = False,
@@ -484,8 +782,10 @@ class SyrianPound(Currency):
             symbol='ل.س',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='ل.س',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='٠١٢٣٤٥٦٧٨٩-',
             international=international)
