@@ -29,6 +29,8 @@ class IranianRial(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 2,
         decimal_sign (str, optional): Decimal symbol. Defaults to '٫'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '٬'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -46,6 +48,7 @@ class IranianRial(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = '\u066B',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '\u066C',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = False,
@@ -64,8 +67,10 @@ class IranianRial(Currency):
             symbol='﷼',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='﷼',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='۰۱۲۳۴۵۶۷۸۹-',
             international=international)
@@ -80,7 +85,7 @@ class RialOmani(Currency):
         >>> rial_omani = RialOmani(
         ...     amount=123456.789)
         >>> print(rial_omani)
-        ١٢٣٬٤٥٦٫٧٨٩ ر.ع.
+        ر.ع. ١٢٣٬٤٥٦٫٧٨٩
 
     For more details see `multicurrency.currency.Currency` .
 
@@ -89,6 +94,8 @@ class RialOmani(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 3,
         decimal_sign (str, optional): Decimal symbol. Defaults to '٫'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '٬'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -96,7 +103,7 @@ class RialOmani(Currency):
         symbol_separator (str, optional): Separation between the symbol
             and the value. Defaults to ' '.
         symbol_ahead (bool, optional): True if symbol goes ahead of the
-            value. False otherwise. Defaults to False.
+            value. False otherwise. Defaults to True.
     """
 
     __slots__ = []
@@ -106,9 +113,10 @@ class RialOmani(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 3,
             decimal_sign: Optional[str] = '\u066B',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '\u066C',
             international: Optional[bool] = False,
-            symbol_ahead: Optional[bool] = False,
+            symbol_ahead: Optional[bool] = True,
             symbol_separator: Optional[str] = '\u00A0',
             **other) -> 'RialOmani':
         """Class creator.
@@ -124,8 +132,10 @@ class RialOmani(Currency):
             symbol='ر.ع.',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='ر.ع.',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='٠١٢٣٤٥٦٧٨٩-',
             international=international)
@@ -140,7 +150,7 @@ class QatariRial(Currency):
         >>> qatari_rial = QatariRial(
         ...     amount=123456.789)
         >>> print(qatari_rial)
-        ١٢٣٬٤٥٦٫٧٩ ر.ق
+        ر.ق. ١٢٣٬٤٥٦٫٧٩
 
     For more details see `multicurrency.currency.Currency` .
 
@@ -149,6 +159,8 @@ class QatariRial(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 2,
         decimal_sign (str, optional): Decimal symbol. Defaults to '٫'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '٬'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -156,7 +168,7 @@ class QatariRial(Currency):
         symbol_separator (str, optional): Separation between the symbol
             and the value. Defaults to ' '.
         symbol_ahead (bool, optional): True if symbol goes ahead of the
-            value. False otherwise. Defaults to False.
+            value. False otherwise. Defaults to True.
     """
 
     __slots__ = []
@@ -166,9 +178,10 @@ class QatariRial(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = '\u066B',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '\u066C',
             international: Optional[bool] = False,
-            symbol_ahead: Optional[bool] = False,
+            symbol_ahead: Optional[bool] = True,
             symbol_separator: Optional[str] = '\u00A0',
             **other) -> 'QatariRial':
         """Class creator.
@@ -181,11 +194,13 @@ class QatariRial(Currency):
             amount=amount,
             alpha_code='QAR',
             numeric_code='634',
-            symbol='ر.ق',
+            symbol='ر.ق.',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='ر.ق.',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='٠١٢٣٤٥٦٧٨٩-',
             international=international)
@@ -209,6 +224,8 @@ class YemeniRial(Currency):
         decimal_places (int, optional): Number of decimal places for the
             currency representation. Defaults to 2,
         decimal_sign (str, optional): Decimal symbol. Defaults to '٫'.
+        grouping_places (int, optional): Number of digits for grouping.
+            Defaults to 3,
         grouping_sign (str, optional): Grouping symbol. Defaults to '٬'.
         international (bool, optional): Identifies the currency using
             the 'currency' value instead of the 'symbol'. Defaults to
@@ -226,6 +243,7 @@ class YemeniRial(Currency):
             amount: Union[int, float, Decimal],
             decimal_places: Optional[int] = 2,
             decimal_sign: Optional[str] = '\u066B',
+            grouping_places: Optional[int] = 3,
             grouping_sign: Optional[str] = '\u066C',
             international: Optional[bool] = False,
             symbol_ahead: Optional[bool] = False,
@@ -244,8 +262,10 @@ class YemeniRial(Currency):
             symbol='﷼',
             symbol_separator=symbol_separator,
             symbol_ahead=symbol_ahead,
+            localized_symbol='﷼',
             decimal_places=decimal_places,
             decimal_sign=decimal_sign,
+            grouping_places=grouping_places,
             grouping_sign=grouping_sign,
             convertion='٠١٢٣٤٥٦٧٨٩-',
             international=international)
